@@ -9,7 +9,7 @@ with 'Pod::Weaver::Role::Section';
 
 use Moose::Autobox;
 
-our $VERSION = '0.04'; # VERSION
+our $VERSION = '0.05'; # VERSION
 
 sub weave_section {
   my ($self, $document, $input) = @_;
@@ -51,7 +51,7 @@ __END__
 
 =pod
 
-=encoding utf-8
+=encoding UTF-8
 
 =head1 NAME
 
@@ -59,7 +59,7 @@ Pod::Weaver::Section::Source::DefaultGitHub - Add a SOURCE section (repository d
 
 =head1 VERSION
 
-version 0.04
+This document describes version 0.05 of Pod::Weaver::Section::Source::DefaultGitHub (from Perl distribution Pod-Weaver-Section-Source-DefaultGitHub), released on 2015-01-07.
 
 =head1 SYNOPSIS
 
@@ -93,13 +93,11 @@ Please visit the project's homepage at L<https://metacpan.org/release/Pod-Weaver
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/sharyanto/perl-Pod-Weaver-Section-Source-DefaultGitHub>.
+Source repository is at L<https://github.com/perlancar/perl-Pod-Weaver-Section-Source-DefaultGitHub>.
 
 =head1 BUGS
 
-Please report any bugs or feature requests on the bugtracker website
-https://rt.cpan.org/Public/Dist/Display.html?Name=Pod-Weaver-Section-Source
--DefaultGitHub
+Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Pod-Weaver-Section-Source-DefaultGitHub>
 
 When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
@@ -107,11 +105,11 @@ feature.
 
 =head1 AUTHOR
 
-Steven Haryanto <stevenharyanto@gmail.com>
+perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Steven Haryanto.
+This software is copyright (c) 2015 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
